@@ -323,14 +323,25 @@ do_dump (MsOle *ole)
 	char        *ptr;
 	MsOleStream *stream;
 	guint8      *buffer;
+	gchar	    *tname;
 
 	ptr = arg_data [arg_cur++];
 	if (!ptr) {
 		printf ("Need a stream name\n");
 		return;
 	}
-       
-	if (test_stream_open (&stream, ole, cur_dir, ptr, 'r') !=
+
+	tname = g_strdup (ptr);
+	if (strcmp(tname, "SummaryInformation") == 0) {
+	        printf ("Changing name to prepend 005\n");
+		tname = "\05SummaryInformation";
+	}
+	if (strcmp(tname, "DocumentSummaryInformation") == 0) {
+	        printf ("Changing name to prepend 005\n");
+		tname = "\05DocumentSummaryInformation";
+	}
+	
+	if (test_stream_open (&stream, ole, cur_dir, tname, 'r') !=
 	    MS_OLE_ERR_OK) {
 		printf ("Error opening '%s'\n", ptr);
 		return;
@@ -793,13 +804,15 @@ do_copyout (MsOle *ole)
 static void
 dump_vba (MsOle *f)
 {
-	const char *vbapath = "/_VBA_PROJECT_CUR";
-	char **dir;
-	MsOleStream *s;
-	MsOleStat    st;
-	char *txt;
-	int   i;
-	int   module_count;
+	const char	*vbapath = "/_VBA_PROJECT_CUR";
+	char		**dir;
+	char		*txt;
+
+	int		 i;
+	int		 module_count;
+
+	MsOleStream	*s;
+	MsOleStat	 st;
 
 	if (ms_ole_stat (&st, f, vbapath, "") != MS_OLE_ERR_OK ||
 	    st.type == MsOleStreamT) {
@@ -837,7 +850,7 @@ dump_vba (MsOle *f)
 		    MS_OLE_ERR_OK)
 			printf ("Error opening %s\n", dir [i]);
 		else {
-			MsOleVba *vba;
+			MsOleVba	*vba;
 
 			vba = ms_ole_vba_open (s);
 			if (!vba)
